[fdo-commits] r705 - trunk/Providers/GenericRdbms/Src/UnitTest/Odbc

svn_fdo at osgeo.org svn_fdo at osgeo.org
Mon Jan 29 15:01:37 EST 2007


Author: gavincramer
Date: 2007-01-29 15:01:37 -0500 (Mon, 29 Jan 2007)
New Revision: 705

Modified:
   trunk/Providers/GenericRdbms/Src/UnitTest/Odbc/OdbcFdoConnectTest.cpp
Log:
Port FDO335 from 3.2.x to trunk

Modified: trunk/Providers/GenericRdbms/Src/UnitTest/Odbc/OdbcFdoConnectTest.cpp
===================================================================
--- trunk/Providers/GenericRdbms/Src/UnitTest/Odbc/OdbcFdoConnectTest.cpp	2007-01-29 19:58:20 UTC (rev 704)
+++ trunk/Providers/GenericRdbms/Src/UnitTest/Odbc/OdbcFdoConnectTest.cpp	2007-01-29 20:01:37 UTC (rev 705)
@@ -281,9 +281,9 @@
             }
         }
 
         // Read the features too.  While this hard-codes the class name,
         // note that it is the only one reported earlier (e.g. other tables are
         // invisible with the configuration file in place).
         FdoPtr<FdoISelect> selectCmd = (FdoISelect*)connection->CreateCommand(FdoCommandType_Select);
         selectCmd->SetFeatureClassName(L"Acdb:Polyline");
         FdoPtr<FdoIFeatureReader> reader = selectCmd->Execute();
@@ -293,9 +293,20 @@
             numFeatures++;
             UnitTestUtil::ProcessFeature(reader);
         }
-        printf("   %i feature(s) read\n", numFeatures);
+        printf("   %i feature(s) read from Polyline\n", numFeatures);
         reader->Close();
 
+        selectCmd->SetFeatureClassName(L"Acdb:Table1");
+        reader = selectCmd->Execute();
+        numFeatures = 0;
+        while (reader->ReadNext())
+        {
+            numFeatures++;
+            UnitTestUtil::ProcessFeature(reader);
+        }
+        printf("   %i feature(s) read from Table1\n", numFeatures);
+        reader->Close();
+
         // This is not currently written to a file for checking, but it is handy
         // for debugging.
         FdoIoMemoryStreamP schemaStream = FdoIoMemoryStream::Create();
@@ -281,9 +281,9 @@
         }
 
-        // Read the features too.  While this hard-codes the class name,
-        // note that it is the only one reported earlier (e.g. other tables are
-        // invisible with the configuration file in place).
+        // Read the features too.  Note that these hard-coded class names
+        // "Polyline" and "Table1" are the only ones reported earlier
+        // (e.g. other tables are invisible with the configuration file in place).
         FdoPtr<FdoISelect> selectCmd = (FdoISelect*)connection->CreateCommand(FdoCommandType_Select);
         selectCmd->SetFeatureClassName(L"Acdb:Polyline");



More information about the fdo-commits mailing list